@@ -1,3 +1,3 @@
 from .stowage import Stowage
 from .partitioning import Partitioning
-from .query import field
+from .dataset import Dataset, field
