@@ -1,9 +1,10 @@
-from typing import List, Dict
+from typing import List, Dict, Union, Optional
 
 
 class Partitioning:
-    def __init__(self, default: str | List[str] | None = None):
-        self.default: str | List[str] | None = None
+    """ Dictionary-like object for specifying the partitioning of multiple datasets. """
+    def __init__(self, default: Optional[Union[str, List[str]]] = None):
+        self.default: Optional[Union[str, List[str]]] = None
         if default is not None and isinstance(default, str):
             self.default = [default]
         elif default is not None:
@@ -13,8 +14,9 @@ class Partitioning:
 
     @staticmethod
     def from_dict(
-        partitions: Dict[str, List[str]], default: str | List[str] | None = None
-    ):
+        partitions: Dict[str, List[str]],
+        default: Optional[Union[str, List[str]]] = None,
+    ) -> "Partitioning":
         partitioning = Partitioning(default)
         partitioning.update(partitions)
         return partitioning
